@@ -70,19 +70,19 @@
 #' @examples
 #' \dontrun{
 #' library(largeVis)
-#' # The spiral dataset can be downloaded from https://github.com/elbamos/clusteringdatasets
+#' library(clusteringdatasets)  # See https://github.com/elbamos/clusteringdatasets
 #' data(spiral)
 #' dat <- as.matrix(spiral[, 1:2])
 #' neighbors <- randomProjectionTreeSearch(t(dat), K = 10, tree_threshold = 100,
-#'                                        max_iter = 5)
+#'                                        max_iter = 5, threads = 1)
 #' edges <- buildEdgeMatrix(t(dat), neighbors)
-#' clusters <- hdbscan(edges, neighbors = neighbors, verbose = FALSE)
+#' clusters <- hdbscan(edges, neighbors = neighbors, verbose = FALSE, threads = 1)
 #'
 #' # Calling largeVis while setting sgd_batches to 1 is
 #' # the simplest way to generate the data structures neeeded for hdbscan
-#' spiralVis <- largeVis(t(dat), K = 10, tree_threshold = 100, max_iter = 5, sgd_batches = 1)
-#' clusters <- hdbscan(spiralVis, verbose = FALSE)
-#'
+#' spiralVis <- largeVis(t(dat), K = 10, tree_threshold = 100, max_iter = 5,
+#'                       sgd_batches = 1, threads = 1)
+#' clusters <- hdbscan(spiralVis, verbose = FALSE, threads = 1)
 #' # The gplot function helps to visualize the clustering
 #' largeHighDimensionalDataset <- matrix(rnorm(50000), ncol = 50)
 #' vis <- largeVis(largeHighDimensionalDataset)
@@ -95,13 +95,15 @@ hdbscan <- function(edges, neighbors = NULL, minPts = 20, K = 5,
 										threads = NULL,
 										verbose = getOption("verbose", TRUE)) {
 
-	if (inherits(edges, "edgematrix")) edges <- toMatrix(edges)
-	if (inherits(edges, "largeVis")) {
+	if (inherits(edges, "edgematrix")) {
+		edges <- t(toMatrix(edges))
+	} else if (inherits(edges, "largeVis")) {
 		if (missing(neighbors)) neighbors <- edges$knns
-		edges <- toMatrix(edges$edges)
+		edges <- t(toMatrix(edges$edges))
 	} else {
-		if (is.null(neighbors)) stop("Neighbors must be specified unless a largeVis object is given.")
+		stop("edges must be either an edgematrix or a largeVis object")
 	}
+	if (is.null(edges) || is.null(neighbors)) stop("Both edges and neighbors must be specified (or use a largeVis object)")
 
 	if (!is.null(neighbors)) {
 		neighbors[is.na(neighbors)] <- -1
