@@ -1,8 +1,14 @@
 #ifndef _LARGEVIS
 #define _LARGEVIS
-//#ifdef _WIN32
-//#define ARMA_32BIT_WORD
-//#endif
+
+#ifndef __llvm__
+#ifndef __clang__
+#if ((__GNUC__ < 5) && (__GNUC_MINOR__ < 9))
+#error largeVis is incompatible with gcc < 4.9. Upgrade gcc or use llvm.
+#endif
+#endif
+#endif
+
 #include <RcppArmadillo.h>
 
 #ifdef _OPENMP
